@@ -426,8 +426,8 @@ BOOL GetMenuName(NOTXSPROC HWND hwnd, int nID, char *Name);
 // BOOL GetAcceleratorName(NOTXSPROC int nID, char *Name);
 // BOOL GetTimerName(NOTXSPROC HWND hwnd, UINT nID, char *Name);
 // BOOL GetNotifyIconName(NOTXSPROC HWND hwnd, UINT nID, char *Name);
-DWORD CALLBACK RichEditSave(DWORD dwCookie, LPBYTE pbBuff, LONG cb, LONG FAR *pcb);
-DWORD CALLBACK RichEditLoad(DWORD dwCookie, LPBYTE pbBuff, LONG cb, LONG FAR *pcb);
+DWORD CALLBACK RichEditSave(DWORD_PTR dwCookie, LPBYTE pbBuff, LONG cb, LONG FAR *pcb);
+DWORD CALLBACK RichEditLoad(DWORD_PTR dwCookie, LPBYTE pbBuff, LONG cb, LONG FAR *pcb);
 int CALLBACK BrowseForFolderProc(HWND hWnd, UINT uMsg, LPARAM lParam, LPARAM lpData);
 int AdjustSplitterCoord(NOTXSPROC LPPERLWIN32GUI_USERDATA perlud, int x, int w, HWND phwnd);
 void DrawSplitter(NOTXSPROC HWND hwnd, int x, int y, int w, int h);
